package com.czsj.web.controller.account;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.account.domain.CzsjMemberTag;
import com.czsj.account.service.ICzsjMemberTagService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 会员标签Controller
 * 
 * @author czsj
 * @date 2024-12-01
 */
@RestController
@RequestMapping("/account/tag")
public class CzsjMemberTagController extends BaseController
{
    @Autowired
    private ICzsjMemberTagService czsjMemberTagService;

    /**
     * 查询会员标签列表
     */
    @PreAuthorize("@ss.hasPermi('account:tag:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjMemberTag czsjMemberTag)
    {
        startPage();
        List<CzsjMemberTag> list = czsjMemberTagService.selectCzsjMemberTagList(czsjMemberTag);
        return getDataTable(list);
    }

    /**
     * 导出会员标签列表
     */
    @PreAuthorize("@ss.hasPermi('account:tag:export')")
    @Log(title = "会员标签", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjMemberTag czsjMemberTag)
    {
        List<CzsjMemberTag> list = czsjMemberTagService.selectCzsjMemberTagList(czsjMemberTag);
        ExcelUtil<CzsjMemberTag> util = new ExcelUtil<CzsjMemberTag>(CzsjMemberTag.class);
        util.exportExcel(response, list, "会员标签数据");
    }

    /**
     * 获取会员标签详细信息
     */
    @PreAuthorize("@ss.hasPermi('account:tag:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjMemberTagService.selectCzsjMemberTagByUid(uid));
    }

    /**
     * 新增会员标签
     */
    @PreAuthorize("@ss.hasPermi('account:tag:add')")
    @Log(title = "会员标签", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjMemberTag czsjMemberTag)
    {
        return toAjax(czsjMemberTagService.insertCzsjMemberTag(czsjMemberTag));
    }

    /**
     * 修改会员标签
     */
    @PreAuthorize("@ss.hasPermi('account:tag:edit')")
    @Log(title = "会员标签", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjMemberTag czsjMemberTag)
    {
        return toAjax(czsjMemberTagService.updateCzsjMemberTag(czsjMemberTag));
    }

    /**
     * 删除会员标签
     */
    @PreAuthorize("@ss.hasPermi('account:tag:remove')")
    @Log(title = "会员标签", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjMemberTagService.deleteCzsjMemberTagByUids(uids));
    }
}
