package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxAccount;
import com.czsj.wechat.service.ICzsjWxAccountService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 微信公众号Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/account")
public class CzsjWxAccountController extends BaseController
{
    @Autowired
    private ICzsjWxAccountService czsjWxAccountService;

    /**
     * 查询微信公众号列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxAccount czsjWxAccount)
    {
        startPage();
        List<CzsjWxAccount> list = czsjWxAccountService.selectCzsjWxAccountList(czsjWxAccount);
        return getDataTable(list);
    }

    /**
     * 导出微信公众号列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:export')")
    @Log(title = "微信公众号", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxAccount czsjWxAccount)
    {
        List<CzsjWxAccount> list = czsjWxAccountService.selectCzsjWxAccountList(czsjWxAccount);
        ExcelUtil<CzsjWxAccount> util = new ExcelUtil<CzsjWxAccount>(CzsjWxAccount.class);
        util.exportExcel(response, list, "微信公众号数据");
    }

    /**
     * 获取微信公众号详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxAccountService.selectCzsjWxAccountByUid(uid));
    }

    /**
     * 新增微信公众号
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:add')")
    @Log(title = "微信公众号", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxAccount czsjWxAccount)
    {
        return toAjax(czsjWxAccountService.insertCzsjWxAccount(czsjWxAccount));
    }

    /**
     * 修改微信公众号
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:edit')")
    @Log(title = "微信公众号", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxAccount czsjWxAccount)
    {
        return toAjax(czsjWxAccountService.updateCzsjWxAccount(czsjWxAccount));
    }

    /**
     * 删除微信公众号
     */
    @PreAuthorize("@ss.hasPermi('wechat:account:remove')")
    @Log(title = "微信公众号", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxAccountService.deleteCzsjWxAccountByUids(uids));
    }
}
