package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxMessage;
import com.czsj.wechat.service.ICzsjWxMessageService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 微信消息Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/message")
public class CzsjWxMessageController extends BaseController
{
    @Autowired
    private ICzsjWxMessageService czsjWxMessageService;

    /**
     * 查询微信消息列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxMessage czsjWxMessage)
    {
        startPage();
        List<CzsjWxMessage> list = czsjWxMessageService.selectCzsjWxMessageList(czsjWxMessage);
        return getDataTable(list);
    }

    /**
     * 导出微信消息列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:export')")
    @Log(title = "微信消息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxMessage czsjWxMessage)
    {
        List<CzsjWxMessage> list = czsjWxMessageService.selectCzsjWxMessageList(czsjWxMessage);
        ExcelUtil<CzsjWxMessage> util = new ExcelUtil<CzsjWxMessage>(CzsjWxMessage.class);
        util.exportExcel(response, list, "微信消息数据");
    }

    /**
     * 获取微信消息详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxMessageService.selectCzsjWxMessageByUid(uid));
    }

    /**
     * 新增微信消息
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:add')")
    @Log(title = "微信消息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxMessage czsjWxMessage)
    {
        return toAjax(czsjWxMessageService.insertCzsjWxMessage(czsjWxMessage));
    }

    /**
     * 修改微信消息
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:edit')")
    @Log(title = "微信消息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxMessage czsjWxMessage)
    {
        return toAjax(czsjWxMessageService.updateCzsjWxMessage(czsjWxMessage));
    }

    /**
     * 删除微信消息
     */
    @PreAuthorize("@ss.hasPermi('wechat:message:remove')")
    @Log(title = "微信消息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxMessageService.deleteCzsjWxMessageByUids(uids));
    }
}
