package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxQrCode;
import com.czsj.wechat.service.ICzsjWxQrCodeService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 公众号二维码Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/code")
public class CzsjWxQrCodeController extends BaseController
{
    @Autowired
    private ICzsjWxQrCodeService czsjWxQrCodeService;

    /**
     * 查询公众号二维码列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxQrCode czsjWxQrCode)
    {
        startPage();
        List<CzsjWxQrCode> list = czsjWxQrCodeService.selectCzsjWxQrCodeList(czsjWxQrCode);
        return getDataTable(list);
    }

    /**
     * 导出公众号二维码列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:export')")
    @Log(title = "公众号二维码", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxQrCode czsjWxQrCode)
    {
        List<CzsjWxQrCode> list = czsjWxQrCodeService.selectCzsjWxQrCodeList(czsjWxQrCode);
        ExcelUtil<CzsjWxQrCode> util = new ExcelUtil<CzsjWxQrCode>(CzsjWxQrCode.class);
        util.exportExcel(response, list, "公众号二维码数据");
    }

    /**
     * 获取公众号二维码详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxQrCodeService.selectCzsjWxQrCodeByUid(uid));
    }

    /**
     * 新增公众号二维码
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:add')")
    @Log(title = "公众号二维码", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxQrCode czsjWxQrCode)
    {
        return toAjax(czsjWxQrCodeService.insertCzsjWxQrCode(czsjWxQrCode));
    }

    /**
     * 修改公众号二维码
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:edit')")
    @Log(title = "公众号二维码", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxQrCode czsjWxQrCode)
    {
        return toAjax(czsjWxQrCodeService.updateCzsjWxQrCode(czsjWxQrCode));
    }

    /**
     * 删除公众号二维码
     */
    @PreAuthorize("@ss.hasPermi('wechat:code:remove')")
    @Log(title = "公众号二维码", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxQrCodeService.deleteCzsjWxQrCodeByUids(uids));
    }
}
