package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxReplyRule;
import com.czsj.wechat.service.ICzsjWxReplyRuleService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 微信消息回复规则Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/rule")
public class CzsjWxReplyRuleController extends BaseController
{
    @Autowired
    private ICzsjWxReplyRuleService czsjWxReplyRuleService;

    /**
     * 查询微信消息回复规则列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxReplyRule czsjWxReplyRule)
    {
        startPage();
        List<CzsjWxReplyRule> list = czsjWxReplyRuleService.selectCzsjWxReplyRuleList(czsjWxReplyRule);
        return getDataTable(list);
    }

    /**
     * 导出微信消息回复规则列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:export')")
    @Log(title = "微信消息回复规则", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxReplyRule czsjWxReplyRule)
    {
        List<CzsjWxReplyRule> list = czsjWxReplyRuleService.selectCzsjWxReplyRuleList(czsjWxReplyRule);
        ExcelUtil<CzsjWxReplyRule> util = new ExcelUtil<CzsjWxReplyRule>(CzsjWxReplyRule.class);
        util.exportExcel(response, list, "微信消息回复规则数据");
    }

    /**
     * 获取微信消息回复规则详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxReplyRuleService.selectCzsjWxReplyRuleByUid(uid));
    }

    /**
     * 新增微信消息回复规则
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:add')")
    @Log(title = "微信消息回复规则", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxReplyRule czsjWxReplyRule)
    {
        return toAjax(czsjWxReplyRuleService.insertCzsjWxReplyRule(czsjWxReplyRule));
    }

    /**
     * 修改微信消息回复规则
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:edit')")
    @Log(title = "微信消息回复规则", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxReplyRule czsjWxReplyRule)
    {
        return toAjax(czsjWxReplyRuleService.updateCzsjWxReplyRule(czsjWxReplyRule));
    }

    /**
     * 删除微信消息回复规则
     */
    @PreAuthorize("@ss.hasPermi('wechat:rule:remove')")
    @Log(title = "微信消息回复规则", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxReplyRuleService.deleteCzsjWxReplyRuleByUids(uids));
    }
}
