package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxTemplate;
import com.czsj.wechat.service.ICzsjWxTemplateService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 微信消息模板Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/template")
public class CzsjWxTemplateController extends BaseController
{
    @Autowired
    private ICzsjWxTemplateService czsjWxTemplateService;

    /**
     * 查询微信消息模板列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxTemplate czsjWxTemplate)
    {
        startPage();
        List<CzsjWxTemplate> list = czsjWxTemplateService.selectCzsjWxTemplateList(czsjWxTemplate);
        return getDataTable(list);
    }

    /**
     * 导出微信消息模板列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:export')")
    @Log(title = "微信消息模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxTemplate czsjWxTemplate)
    {
        List<CzsjWxTemplate> list = czsjWxTemplateService.selectCzsjWxTemplateList(czsjWxTemplate);
        ExcelUtil<CzsjWxTemplate> util = new ExcelUtil<CzsjWxTemplate>(CzsjWxTemplate.class);
        util.exportExcel(response, list, "微信消息模板数据");
    }

    /**
     * 获取微信消息模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxTemplateService.selectCzsjWxTemplateByUid(uid));
    }

    /**
     * 新增微信消息模板
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:add')")
    @Log(title = "微信消息模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxTemplate czsjWxTemplate)
    {
        return toAjax(czsjWxTemplateService.insertCzsjWxTemplate(czsjWxTemplate));
    }

    /**
     * 修改微信消息模板
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:edit')")
    @Log(title = "微信消息模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxTemplate czsjWxTemplate)
    {
        return toAjax(czsjWxTemplateService.updateCzsjWxTemplate(czsjWxTemplate));
    }

    /**
     * 删除微信消息模板
     */
    @PreAuthorize("@ss.hasPermi('wechat:template:remove')")
    @Log(title = "微信消息模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxTemplateService.deleteCzsjWxTemplateByUids(uids));
    }
}
