package com.czsj.web.controller.wechat;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.wechat.domain.CzsjWxTemplateLog;
import com.czsj.wechat.service.ICzsjWxTemplateLogService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 微信消息模板日志Controller
 * 
 * @author czsj
 * @date 2024-12-07
 */
@RestController
@RequestMapping("/wechat/log")
public class CzsjWxTemplateLogController extends BaseController
{
    @Autowired
    private ICzsjWxTemplateLogService czsjWxTemplateLogService;

    /**
     * 查询微信消息模板日志列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:list')")
    @GetMapping("/list")
    public TableDataInfo list(CzsjWxTemplateLog czsjWxTemplateLog)
    {
        startPage();
        List<CzsjWxTemplateLog> list = czsjWxTemplateLogService.selectCzsjWxTemplateLogList(czsjWxTemplateLog);
        return getDataTable(list);
    }

    /**
     * 导出微信消息模板日志列表
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:export')")
    @Log(title = "微信消息模板日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CzsjWxTemplateLog czsjWxTemplateLog)
    {
        List<CzsjWxTemplateLog> list = czsjWxTemplateLogService.selectCzsjWxTemplateLogList(czsjWxTemplateLog);
        ExcelUtil<CzsjWxTemplateLog> util = new ExcelUtil<CzsjWxTemplateLog>(CzsjWxTemplateLog.class);
        util.exportExcel(response, list, "微信消息模板日志数据");
    }

    /**
     * 获取微信消息模板日志详细信息
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:query')")
    @GetMapping(value = "/{uid}")
    public AjaxResult getInfo(@PathVariable("uid") Long uid)
    {
        return success(czsjWxTemplateLogService.selectCzsjWxTemplateLogByUid(uid));
    }

    /**
     * 新增微信消息模板日志
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:add')")
    @Log(title = "微信消息模板日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CzsjWxTemplateLog czsjWxTemplateLog)
    {
        return toAjax(czsjWxTemplateLogService.insertCzsjWxTemplateLog(czsjWxTemplateLog));
    }

    /**
     * 修改微信消息模板日志
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:edit')")
    @Log(title = "微信消息模板日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CzsjWxTemplateLog czsjWxTemplateLog)
    {
        return toAjax(czsjWxTemplateLogService.updateCzsjWxTemplateLog(czsjWxTemplateLog));
    }

    /**
     * 删除微信消息模板日志
     */
    @PreAuthorize("@ss.hasPermi('wechat:log:remove')")
    @Log(title = "微信消息模板日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{uids}")
    public AjaxResult remove(@PathVariable Long[] uids)
    {
        return toAjax(czsjWxTemplateLogService.deleteCzsjWxTemplateLogByUids(uids));
    }
}
