package com.czsj.account.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.account.mapper.CzsjMemberRelationMapper;
import com.czsj.account.domain.CzsjMemberRelation;
import com.czsj.account.service.ICzsjMemberRelationService;

/**
 * 会员关系Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-01
 */
@Service
public class CzsjMemberRelationServiceImpl implements ICzsjMemberRelationService 
{
    @Autowired
    private CzsjMemberRelationMapper czsjMemberRelationMapper;

    /**
     * 查询会员关系
     * 
     * @param uid 会员关系主键
     * @return 会员关系
     */
    @Override
    public CzsjMemberRelation selectCzsjMemberRelationByUid(Long uid)
    {
        return czsjMemberRelationMapper.selectCzsjMemberRelationByUid(uid);
    }

    /**
     * 查询会员关系列表
     * 
     * @param czsjMemberRelation 会员关系
     * @return 会员关系
     */
    @Override
    public List<CzsjMemberRelation> selectCzsjMemberRelationList(CzsjMemberRelation czsjMemberRelation)
    {
        return czsjMemberRelationMapper.selectCzsjMemberRelationList(czsjMemberRelation);
    }

    /**
     * 新增会员关系
     * 
     * @param czsjMemberRelation 会员关系
     * @return 结果
     */
    @Override
    public int insertCzsjMemberRelation(CzsjMemberRelation czsjMemberRelation)
    {
        czsjMemberRelation.setCreateTime(DateUtils.getNowDate());
        return czsjMemberRelationMapper.insertCzsjMemberRelation(czsjMemberRelation);
    }

    /**
     * 修改会员关系
     * 
     * @param czsjMemberRelation 会员关系
     * @return 结果
     */
    @Override
    public int updateCzsjMemberRelation(CzsjMemberRelation czsjMemberRelation)
    {
        czsjMemberRelation.setUpdateTime(DateUtils.getNowDate());
        return czsjMemberRelationMapper.updateCzsjMemberRelation(czsjMemberRelation);
    }

    /**
     * 批量删除会员关系
     * 
     * @param uids 需要删除的会员关系主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberRelationByUids(Long[] uids)
    {
        return czsjMemberRelationMapper.deleteCzsjMemberRelationByUids(uids);
    }

    /**
     * 删除会员关系信息
     * 
     * @param uid 会员关系主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberRelationByUid(Long uid)
    {
        return czsjMemberRelationMapper.deleteCzsjMemberRelationByUid(uid);
    }
}
