package com.czsj.account.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.account.mapper.CzsjMemberMapper;
import com.czsj.account.domain.CzsjMember;
import com.czsj.account.service.ICzsjMemberService;

/**
 * 会员信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-01
 */
@Service
public class CzsjMemberServiceImpl implements ICzsjMemberService 
{
    @Autowired
    private CzsjMemberMapper czsjMemberMapper;

    /**
     * 查询会员信息
     * 
     * @param uid 会员信息主键
     * @return 会员信息
     */
    @Override
    public CzsjMember selectCzsjMemberByUid(Long uid)
    {
        return czsjMemberMapper.selectCzsjMemberByUid(uid);
    }

    /**
     * 查询会员信息列表
     * 
     * @param czsjMember 会员信息
     * @return 会员信息
     */
    @Override
    public List<CzsjMember> selectCzsjMemberList(CzsjMember czsjMember)
    {
        return czsjMemberMapper.selectCzsjMemberList(czsjMember);
    }

    /**
     * 新增会员信息
     * 
     * @param czsjMember 会员信息
     * @return 结果
     */
    @Override
    public int insertCzsjMember(CzsjMember czsjMember)
    {
        czsjMember.setCreateTime(DateUtils.getNowDate());
        return czsjMemberMapper.insertCzsjMember(czsjMember);
    }

    /**
     * 修改会员信息
     * 
     * @param czsjMember 会员信息
     * @return 结果
     */
    @Override
    public int updateCzsjMember(CzsjMember czsjMember)
    {
        czsjMember.setUpdateTime(DateUtils.getNowDate());
        return czsjMemberMapper.updateCzsjMember(czsjMember);
    }

    /**
     * 批量删除会员信息
     * 
     * @param uids 需要删除的会员信息主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberByUids(Long[] uids)
    {
        return czsjMemberMapper.deleteCzsjMemberByUids(uids);
    }

    /**
     * 删除会员信息信息
     * 
     * @param uid 会员信息主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberByUid(Long uid)
    {
        return czsjMemberMapper.deleteCzsjMemberByUid(uid);
    }
}
