package com.czsj.account.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.account.mapper.CzsjMemberSignMapper;
import com.czsj.account.domain.CzsjMemberSign;
import com.czsj.account.service.ICzsjMemberSignService;

/**
 * 会员签到记录Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-01
 */
@Service
public class CzsjMemberSignServiceImpl implements ICzsjMemberSignService 
{
    @Autowired
    private CzsjMemberSignMapper czsjMemberSignMapper;

    /**
     * 查询会员签到记录
     * 
     * @param uid 会员签到记录主键
     * @return 会员签到记录
     */
    @Override
    public CzsjMemberSign selectCzsjMemberSignByUid(Long uid)
    {
        return czsjMemberSignMapper.selectCzsjMemberSignByUid(uid);
    }

    /**
     * 查询会员签到记录列表
     * 
     * @param czsjMemberSign 会员签到记录
     * @return 会员签到记录
     */
    @Override
    public List<CzsjMemberSign> selectCzsjMemberSignList(CzsjMemberSign czsjMemberSign)
    {
        return czsjMemberSignMapper.selectCzsjMemberSignList(czsjMemberSign);
    }

    /**
     * 新增会员签到记录
     * 
     * @param czsjMemberSign 会员签到记录
     * @return 结果
     */
    @Override
    public int insertCzsjMemberSign(CzsjMemberSign czsjMemberSign)
    {
        czsjMemberSign.setCreateTime(DateUtils.getNowDate());
        return czsjMemberSignMapper.insertCzsjMemberSign(czsjMemberSign);
    }

    /**
     * 修改会员签到记录
     * 
     * @param czsjMemberSign 会员签到记录
     * @return 结果
     */
    @Override
    public int updateCzsjMemberSign(CzsjMemberSign czsjMemberSign)
    {
        czsjMemberSign.setUpdateTime(DateUtils.getNowDate());
        return czsjMemberSignMapper.updateCzsjMemberSign(czsjMemberSign);
    }

    /**
     * 批量删除会员签到记录
     * 
     * @param uids 需要删除的会员签到记录主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberSignByUids(Long[] uids)
    {
        return czsjMemberSignMapper.deleteCzsjMemberSignByUids(uids);
    }

    /**
     * 删除会员签到记录信息
     * 
     * @param uid 会员签到记录主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberSignByUid(Long uid)
    {
        return czsjMemberSignMapper.deleteCzsjMemberSignByUid(uid);
    }
}
