package com.czsj.account.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.account.mapper.CzsjMemberTagMapper;
import com.czsj.account.domain.CzsjMemberTag;
import com.czsj.account.service.ICzsjMemberTagService;

/**
 * 会员标签Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-01
 */
@Service
public class CzsjMemberTagServiceImpl implements ICzsjMemberTagService 
{
    @Autowired
    private CzsjMemberTagMapper czsjMemberTagMapper;

    /**
     * 查询会员标签
     * 
     * @param uid 会员标签主键
     * @return 会员标签
     */
    @Override
    public CzsjMemberTag selectCzsjMemberTagByUid(Long uid)
    {
        return czsjMemberTagMapper.selectCzsjMemberTagByUid(uid);
    }

    /**
     * 查询会员标签列表
     * 
     * @param czsjMemberTag 会员标签
     * @return 会员标签
     */
    @Override
    public List<CzsjMemberTag> selectCzsjMemberTagList(CzsjMemberTag czsjMemberTag)
    {
        return czsjMemberTagMapper.selectCzsjMemberTagList(czsjMemberTag);
    }

    /**
     * 新增会员标签
     * 
     * @param czsjMemberTag 会员标签
     * @return 结果
     */
    @Override
    public int insertCzsjMemberTag(CzsjMemberTag czsjMemberTag)
    {
        czsjMemberTag.setCreateTime(DateUtils.getNowDate());
        return czsjMemberTagMapper.insertCzsjMemberTag(czsjMemberTag);
    }

    /**
     * 修改会员标签
     * 
     * @param czsjMemberTag 会员标签
     * @return 结果
     */
    @Override
    public int updateCzsjMemberTag(CzsjMemberTag czsjMemberTag)
    {
        czsjMemberTag.setUpdateTime(DateUtils.getNowDate());
        return czsjMemberTagMapper.updateCzsjMemberTag(czsjMemberTag);
    }

    /**
     * 批量删除会员标签
     * 
     * @param uids 需要删除的会员标签主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberTagByUids(Long[] uids)
    {
        return czsjMemberTagMapper.deleteCzsjMemberTagByUids(uids);
    }

    /**
     * 删除会员标签信息
     * 
     * @param uid 会员标签主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberTagByUid(Long uid)
    {
        return czsjMemberTagMapper.deleteCzsjMemberTagByUid(uid);
    }
}
