package com.czsj.account.service.impl;

import java.util.Date;
import java.util.List;

import com.czsj.common.core.domain.entity.SysUser;
import com.czsj.common.core.domain.model.LoginUser;
import com.czsj.common.utils.DateUtils;
import com.czsj.common.utils.SecurityUtils;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.account.mapper.CzsjMemberWxFansMapper;
import com.czsj.account.domain.CzsjMemberWxFans;
import com.czsj.account.service.ICzsjMemberWxFansService;

/**
 * 会员微信粉丝Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-01
 */
@Service
public class CzsjMemberWxFansServiceImpl implements ICzsjMemberWxFansService 
{
    Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private CzsjMemberWxFansMapper czsjMemberWxFansMapper;
    @Autowired
    private WxMpService wxMpService;

    @Override
    public void unsubscribe(String openid) {
        CzsjMemberWxFans fans = new CzsjMemberWxFans();
        fans.setOpenId(openid);
        fans.setSubscribeStatus(1);
        fans.setUnsubscribeTime(new Date());
        czsjMemberWxFansMapper.updateCzsjMemberWxFans(fans);
    }

    @Override
    public void refreshUserInfo(String openid, String appid) {
        try {
            LoginUser loginUser = SecurityUtils.getLoginUser();
            SysUser currentUser = loginUser.getUser();
            // 获取微信用户基本信息
            logger.info("更新用户信息，openid={}",openid);
            wxMpService.switchover(appid);
            WxMpUser userWxInfo = wxMpService.getUserService().userInfo(openid, null);
            if (userWxInfo == null) {
                logger.error("获取不到用户信息，无法更新,openid:{}",openid);
                return ;
            }
            CzsjMemberWxFans fans = new CzsjMemberWxFans();
            fans.setOpenId(openid);
            List<CzsjMemberWxFans> czsjMemberWxFans = czsjMemberWxFansMapper.selectCzsjMemberWxFansList(fans);
            fans.setAppId(appid);
            fans.setCreateUserId(currentUser.getUserId());
            fans.setUpdateUserId(currentUser.getUserId());
            fans.setUpdateTime(new Date());
            fans.setName(userWxInfo.getNickname());
            fans.setImageUrl(userWxInfo.getHeadImgUrl());
            fans.setSubscribeStatus(0);
            fans.setRemark(userWxInfo.getRemark());
            if (!czsjMemberWxFans.isEmpty()){
                czsjMemberWxFansMapper.updateCzsjMemberWxFans(fans);
            }else {
                fans.setCreateTime(new Date());
                czsjMemberWxFansMapper.insertCzsjMemberWxFans(fans);
            }
        } catch (Exception e) {
            logger.error("更新用户信息失败,openid:{}",openid);
        }
    }

    /**
     * 查询会员微信粉丝
     * 
     * @param uid 会员微信粉丝主键
     * @return 会员微信粉丝
     */
    @Override
    public CzsjMemberWxFans selectCzsjMemberWxFansByUid(Long uid)
    {
        return czsjMemberWxFansMapper.selectCzsjMemberWxFansByUid(uid);
    }

    /**
     * 查询会员微信粉丝列表
     * 
     * @param czsjMemberWxFans 会员微信粉丝
     * @return 会员微信粉丝
     */
    @Override
    public List<CzsjMemberWxFans> selectCzsjMemberWxFansList(CzsjMemberWxFans czsjMemberWxFans)
    {
        return czsjMemberWxFansMapper.selectCzsjMemberWxFansList(czsjMemberWxFans);
    }

    /**
     * 新增会员微信粉丝
     * 
     * @param czsjMemberWxFans 会员微信粉丝
     * @return 结果
     */
    @Override
    public int insertCzsjMemberWxFans(CzsjMemberWxFans czsjMemberWxFans)
    {
        czsjMemberWxFans.setCreateTime(DateUtils.getNowDate());
        return czsjMemberWxFansMapper.insertCzsjMemberWxFans(czsjMemberWxFans);
    }

    /**
     * 修改会员微信粉丝
     * 
     * @param czsjMemberWxFans 会员微信粉丝
     * @return 结果
     */
    @Override
    public int updateCzsjMemberWxFans(CzsjMemberWxFans czsjMemberWxFans)
    {
        czsjMemberWxFans.setUpdateTime(DateUtils.getNowDate());
        return czsjMemberWxFansMapper.updateCzsjMemberWxFans(czsjMemberWxFans);
    }

    /**
     * 批量删除会员微信粉丝
     * 
     * @param uids 需要删除的会员微信粉丝主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberWxFansByUids(Long[] uids)
    {
        return czsjMemberWxFansMapper.deleteCzsjMemberWxFansByUids(uids);
    }

    /**
     * 删除会员微信粉丝信息
     * 
     * @param uid 会员微信粉丝主键
     * @return 结果
     */
    @Override
    public int deleteCzsjMemberWxFansByUid(Long uid)
    {
        return czsjMemberWxFansMapper.deleteCzsjMemberWxFansByUid(uid);
    }
}
