package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxAccountMapper;
import com.czsj.wechat.domain.CzsjWxAccount;
import com.czsj.wechat.service.ICzsjWxAccountService;

/**
 * 微信公众号Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxAccountServiceImpl implements ICzsjWxAccountService 
{
    @Autowired
    private CzsjWxAccountMapper czsjWxAccountMapper;

    /**
     * 查询微信公众号
     * 
     * @param uid 微信公众号主键
     * @return 微信公众号
     */
    @Override
    public CzsjWxAccount selectCzsjWxAccountByUid(Long uid)
    {
        return czsjWxAccountMapper.selectCzsjWxAccountByUid(uid);
    }

    /**
     * 查询微信公众号列表
     * 
     * @param czsjWxAccount 微信公众号
     * @return 微信公众号
     */
    @Override
    public List<CzsjWxAccount> selectCzsjWxAccountList(CzsjWxAccount czsjWxAccount)
    {
        return czsjWxAccountMapper.selectCzsjWxAccountList(czsjWxAccount);
    }

    /**
     * 新增微信公众号
     * 
     * @param czsjWxAccount 微信公众号
     * @return 结果
     */
    @Override
    public int insertCzsjWxAccount(CzsjWxAccount czsjWxAccount)
    {
        czsjWxAccount.setCreateTime(DateUtils.getNowDate());
        return czsjWxAccountMapper.insertCzsjWxAccount(czsjWxAccount);
    }

    /**
     * 修改微信公众号
     * 
     * @param czsjWxAccount 微信公众号
     * @return 结果
     */
    @Override
    public int updateCzsjWxAccount(CzsjWxAccount czsjWxAccount)
    {
        czsjWxAccount.setUpdateTime(DateUtils.getNowDate());
        return czsjWxAccountMapper.updateCzsjWxAccount(czsjWxAccount);
    }

    /**
     * 批量删除微信公众号
     * 
     * @param uids 需要删除的微信公众号主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxAccountByUids(Long[] uids)
    {
        return czsjWxAccountMapper.deleteCzsjWxAccountByUids(uids);
    }

    /**
     * 删除微信公众号信息
     * 
     * @param uid 微信公众号主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxAccountByUid(Long uid)
    {
        return czsjWxAccountMapper.deleteCzsjWxAccountByUid(uid);
    }
}
