package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxMessageMapper;
import com.czsj.wechat.domain.CzsjWxMessage;
import com.czsj.wechat.service.ICzsjWxMessageService;

/**
 * 微信消息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxMessageServiceImpl implements ICzsjWxMessageService 
{
    @Autowired
    private CzsjWxMessageMapper czsjWxMessageMapper;

    /**
     * 查询微信消息
     * 
     * @param uid 微信消息主键
     * @return 微信消息
     */
    @Override
    public CzsjWxMessage selectCzsjWxMessageByUid(Long uid)
    {
        return czsjWxMessageMapper.selectCzsjWxMessageByUid(uid);
    }

    /**
     * 查询微信消息列表
     * 
     * @param czsjWxMessage 微信消息
     * @return 微信消息
     */
    @Override
    public List<CzsjWxMessage> selectCzsjWxMessageList(CzsjWxMessage czsjWxMessage)
    {
        return czsjWxMessageMapper.selectCzsjWxMessageList(czsjWxMessage);
    }

    /**
     * 新增微信消息
     * 
     * @param czsjWxMessage 微信消息
     * @return 结果
     */
    @Override
    public int insertCzsjWxMessage(CzsjWxMessage czsjWxMessage)
    {
        czsjWxMessage.setCreateTime(DateUtils.getNowDate());
        return czsjWxMessageMapper.insertCzsjWxMessage(czsjWxMessage);
    }

    /**
     * 修改微信消息
     * 
     * @param czsjWxMessage 微信消息
     * @return 结果
     */
    @Override
    public int updateCzsjWxMessage(CzsjWxMessage czsjWxMessage)
    {
        czsjWxMessage.setUpdateTime(DateUtils.getNowDate());
        return czsjWxMessageMapper.updateCzsjWxMessage(czsjWxMessage);
    }

    /**
     * 批量删除微信消息
     * 
     * @param uids 需要删除的微信消息主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxMessageByUids(Long[] uids)
    {
        return czsjWxMessageMapper.deleteCzsjWxMessageByUids(uids);
    }

    /**
     * 删除微信消息信息
     * 
     * @param uid 微信消息主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxMessageByUid(Long uid)
    {
        return czsjWxMessageMapper.deleteCzsjWxMessageByUid(uid);
    }
}
