package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxQrCodeMapper;
import com.czsj.wechat.domain.CzsjWxQrCode;
import com.czsj.wechat.service.ICzsjWxQrCodeService;

/**
 * 公众号二维码Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxQrCodeServiceImpl implements ICzsjWxQrCodeService 
{
    @Autowired
    private CzsjWxQrCodeMapper czsjWxQrCodeMapper;

    /**
     * 查询公众号二维码
     * 
     * @param uid 公众号二维码主键
     * @return 公众号二维码
     */
    @Override
    public CzsjWxQrCode selectCzsjWxQrCodeByUid(Long uid)
    {
        return czsjWxQrCodeMapper.selectCzsjWxQrCodeByUid(uid);
    }

    /**
     * 查询公众号二维码列表
     * 
     * @param czsjWxQrCode 公众号二维码
     * @return 公众号二维码
     */
    @Override
    public List<CzsjWxQrCode> selectCzsjWxQrCodeList(CzsjWxQrCode czsjWxQrCode)
    {
        return czsjWxQrCodeMapper.selectCzsjWxQrCodeList(czsjWxQrCode);
    }

    /**
     * 新增公众号二维码
     * 
     * @param czsjWxQrCode 公众号二维码
     * @return 结果
     */
    @Override
    public int insertCzsjWxQrCode(CzsjWxQrCode czsjWxQrCode)
    {
        czsjWxQrCode.setCreateTime(DateUtils.getNowDate());
        return czsjWxQrCodeMapper.insertCzsjWxQrCode(czsjWxQrCode);
    }

    /**
     * 修改公众号二维码
     * 
     * @param czsjWxQrCode 公众号二维码
     * @return 结果
     */
    @Override
    public int updateCzsjWxQrCode(CzsjWxQrCode czsjWxQrCode)
    {
        czsjWxQrCode.setUpdateTime(DateUtils.getNowDate());
        return czsjWxQrCodeMapper.updateCzsjWxQrCode(czsjWxQrCode);
    }

    /**
     * 批量删除公众号二维码
     * 
     * @param uids 需要删除的公众号二维码主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxQrCodeByUids(Long[] uids)
    {
        return czsjWxQrCodeMapper.deleteCzsjWxQrCodeByUids(uids);
    }

    /**
     * 删除公众号二维码信息
     * 
     * @param uid 公众号二维码主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxQrCodeByUid(Long uid)
    {
        return czsjWxQrCodeMapper.deleteCzsjWxQrCodeByUid(uid);
    }
}
