package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxReplyRuleMapper;
import com.czsj.wechat.domain.CzsjWxReplyRule;
import com.czsj.wechat.service.ICzsjWxReplyRuleService;

/**
 * 微信消息回复规则Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxReplyRuleServiceImpl implements ICzsjWxReplyRuleService 
{
    @Autowired
    private CzsjWxReplyRuleMapper czsjWxReplyRuleMapper;

    /**
     * 查询微信消息回复规则
     * 
     * @param uid 微信消息回复规则主键
     * @return 微信消息回复规则
     */
    @Override
    public CzsjWxReplyRule selectCzsjWxReplyRuleByUid(Long uid)
    {
        return czsjWxReplyRuleMapper.selectCzsjWxReplyRuleByUid(uid);
    }

    /**
     * 查询微信消息回复规则列表
     * 
     * @param czsjWxReplyRule 微信消息回复规则
     * @return 微信消息回复规则
     */
    @Override
    public List<CzsjWxReplyRule> selectCzsjWxReplyRuleList(CzsjWxReplyRule czsjWxReplyRule)
    {
        return czsjWxReplyRuleMapper.selectCzsjWxReplyRuleList(czsjWxReplyRule);
    }

    /**
     * 新增微信消息回复规则
     * 
     * @param czsjWxReplyRule 微信消息回复规则
     * @return 结果
     */
    @Override
    public int insertCzsjWxReplyRule(CzsjWxReplyRule czsjWxReplyRule)
    {
        czsjWxReplyRule.setCreateTime(DateUtils.getNowDate());
        return czsjWxReplyRuleMapper.insertCzsjWxReplyRule(czsjWxReplyRule);
    }

    /**
     * 修改微信消息回复规则
     * 
     * @param czsjWxReplyRule 微信消息回复规则
     * @return 结果
     */
    @Override
    public int updateCzsjWxReplyRule(CzsjWxReplyRule czsjWxReplyRule)
    {
        czsjWxReplyRule.setUpdateTime(DateUtils.getNowDate());
        return czsjWxReplyRuleMapper.updateCzsjWxReplyRule(czsjWxReplyRule);
    }

    /**
     * 批量删除微信消息回复规则
     * 
     * @param uids 需要删除的微信消息回复规则主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxReplyRuleByUids(Long[] uids)
    {
        return czsjWxReplyRuleMapper.deleteCzsjWxReplyRuleByUids(uids);
    }

    /**
     * 删除微信消息回复规则信息
     * 
     * @param uid 微信消息回复规则主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxReplyRuleByUid(Long uid)
    {
        return czsjWxReplyRuleMapper.deleteCzsjWxReplyRuleByUid(uid);
    }
}
