package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxTemplateLogMapper;
import com.czsj.wechat.domain.CzsjWxTemplateLog;
import com.czsj.wechat.service.ICzsjWxTemplateLogService;

/**
 * 微信消息模板日志Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxTemplateLogServiceImpl implements ICzsjWxTemplateLogService 
{
    @Autowired
    private CzsjWxTemplateLogMapper czsjWxTemplateLogMapper;

    /**
     * 查询微信消息模板日志
     * 
     * @param uid 微信消息模板日志主键
     * @return 微信消息模板日志
     */
    @Override
    public CzsjWxTemplateLog selectCzsjWxTemplateLogByUid(Long uid)
    {
        return czsjWxTemplateLogMapper.selectCzsjWxTemplateLogByUid(uid);
    }

    /**
     * 查询微信消息模板日志列表
     * 
     * @param czsjWxTemplateLog 微信消息模板日志
     * @return 微信消息模板日志
     */
    @Override
    public List<CzsjWxTemplateLog> selectCzsjWxTemplateLogList(CzsjWxTemplateLog czsjWxTemplateLog)
    {
        return czsjWxTemplateLogMapper.selectCzsjWxTemplateLogList(czsjWxTemplateLog);
    }

    /**
     * 新增微信消息模板日志
     * 
     * @param czsjWxTemplateLog 微信消息模板日志
     * @return 结果
     */
    @Override
    public int insertCzsjWxTemplateLog(CzsjWxTemplateLog czsjWxTemplateLog)
    {
        czsjWxTemplateLog.setCreateTime(DateUtils.getNowDate());
        return czsjWxTemplateLogMapper.insertCzsjWxTemplateLog(czsjWxTemplateLog);
    }

    /**
     * 修改微信消息模板日志
     * 
     * @param czsjWxTemplateLog 微信消息模板日志
     * @return 结果
     */
    @Override
    public int updateCzsjWxTemplateLog(CzsjWxTemplateLog czsjWxTemplateLog)
    {
        czsjWxTemplateLog.setUpdateTime(DateUtils.getNowDate());
        return czsjWxTemplateLogMapper.updateCzsjWxTemplateLog(czsjWxTemplateLog);
    }

    /**
     * 批量删除微信消息模板日志
     * 
     * @param uids 需要删除的微信消息模板日志主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxTemplateLogByUids(Long[] uids)
    {
        return czsjWxTemplateLogMapper.deleteCzsjWxTemplateLogByUids(uids);
    }

    /**
     * 删除微信消息模板日志信息
     * 
     * @param uid 微信消息模板日志主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxTemplateLogByUid(Long uid)
    {
        return czsjWxTemplateLogMapper.deleteCzsjWxTemplateLogByUid(uid);
    }
}
