package com.czsj.wechat.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.wechat.mapper.CzsjWxTemplateMapper;
import com.czsj.wechat.domain.CzsjWxTemplate;
import com.czsj.wechat.service.ICzsjWxTemplateService;

/**
 * 微信消息模板Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-07
 */
@Service
public class CzsjWxTemplateServiceImpl implements ICzsjWxTemplateService 
{
    @Autowired
    private CzsjWxTemplateMapper czsjWxTemplateMapper;

    /**
     * 查询微信消息模板
     * 
     * @param uid 微信消息模板主键
     * @return 微信消息模板
     */
    @Override
    public CzsjWxTemplate selectCzsjWxTemplateByUid(Long uid)
    {
        return czsjWxTemplateMapper.selectCzsjWxTemplateByUid(uid);
    }

    /**
     * 查询微信消息模板列表
     * 
     * @param czsjWxTemplate 微信消息模板
     * @return 微信消息模板
     */
    @Override
    public List<CzsjWxTemplate> selectCzsjWxTemplateList(CzsjWxTemplate czsjWxTemplate)
    {
        return czsjWxTemplateMapper.selectCzsjWxTemplateList(czsjWxTemplate);
    }

    /**
     * 新增微信消息模板
     * 
     * @param czsjWxTemplate 微信消息模板
     * @return 结果
     */
    @Override
    public int insertCzsjWxTemplate(CzsjWxTemplate czsjWxTemplate)
    {
        czsjWxTemplate.setCreateTime(DateUtils.getNowDate());
        return czsjWxTemplateMapper.insertCzsjWxTemplate(czsjWxTemplate);
    }

    /**
     * 修改微信消息模板
     * 
     * @param czsjWxTemplate 微信消息模板
     * @return 结果
     */
    @Override
    public int updateCzsjWxTemplate(CzsjWxTemplate czsjWxTemplate)
    {
        czsjWxTemplate.setUpdateTime(DateUtils.getNowDate());
        return czsjWxTemplateMapper.updateCzsjWxTemplate(czsjWxTemplate);
    }

    /**
     * 批量删除微信消息模板
     * 
     * @param uids 需要删除的微信消息模板主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxTemplateByUids(Long[] uids)
    {
        return czsjWxTemplateMapper.deleteCzsjWxTemplateByUids(uids);
    }

    /**
     * 删除微信消息模板信息
     * 
     * @param uid 微信消息模板主键
     * @return 结果
     */
    @Override
    public int deleteCzsjWxTemplateByUid(Long uid)
    {
        return czsjWxTemplateMapper.deleteCzsjWxTemplateByUid(uid);
    }
}
